==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/editace/view_zpracovana.php <==
<?php
/**
 * stanislav.elbl, 18.06.2015
 */

namespace RonPortal\Editace;

/**
 * @var ZpracovanaDochazkaBrowser $this
 */

use Ron\DateUtils;
use Ron\Dialog;
use Ron\DialogButton;
use Ron\GuiUtils;
use RonPortal\Controls\FormReportsListView;
use RonPortal\Dochazka\VysledekKontroly;
use RonPortal\Kalendar;
use RonPortal\Prava;

$this ->jeEdit = true; // POZOR! Musi byt, aby byla videt tlacitka, pokud jsou nahore

if ($this ->denniVysledky ->existujeTlacitko('pk_zmenitsmenu')) {
    /** @var Dialog $pk_dialog */
    $pk_dialog = (new Dialog())
        ->setTitle(\Ron\ronText('Zmena_naplanovane_smeny'))
        ->setId('zpracovana_pk_zmenitsmenu')
        ->setWaitMessage(true)
        ->addButton(
            (new DialogButton())
                ->setId('btn_pk_OK')
                ->setValue(\Ron\ronText('Provest'))
        )
        ->addButton(
            (DialogButton::cancelButton('btn_pk_Storno'))
        );

//<!--            <input type="button" id="btn_pk_Storno" class="button" value="--><?//= \Ron\ronText('Cancel')
} else {
    $pk_dialog = null;
}



?>
<style>
    .graficka_timediv { width: <?= $this ->grafickaWidth ?>px }

    <?php if ($this ->denniVysledky ->style) {?>
        <?= $this ->denniVysledky ->style ?>
    <?php } ?>
</style>
<div id="zpracovanadochazka">
    <form class="sendPosition" name="zpracovanadochazkaform" id="zpracovanadochazkaform" method="post" action="?menuid=zpracovanadochazka" >

        <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->denniVysledky ->datumOd) ?>" />
        <input type="hidden" name="osoba" value="<?= $this ->denniVysledky ->pp ->idPP ?>" />

        <input type="hidden" name="x" value="" />
        <input type="hidden" name="y" value="" />

        <!-- tlacitka nahore -->
        <div class="buttons">
            <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" /> <!-- defaultni submit kvuli enter -->
            <span class="zpracovana_tlacitka1">
                <?php $this ->zobrazTlacitka(1); // vlevo nahore  ?>
            </span>

            <?php $this ->volbaZobrazeni(); ?>

            <span class="float-right zpracovana_tlacitka2">
                <?php $this ->zobrazTlacitka(2); // vpravo nahore ?>
            </span>
        </div>


        <?php
            $this ->jeEdit = false;
            $this ->renderTableStart();
        ?>

        <thead class="floating-table-header">
            <tr>
                <?php
                    for ($i = 0; $i < count($this ->denniVysledky ->sloupce); $i++) {
                        if ($this ->denniVysledky ->sloupce[$i] ->typ  &&  $this ->denniVysledky ->sloupce[$i] ->lzeZobrazit) {
                            $this->zobrazHlavickuSloupce($i);
                        }
                    }
                ?>
            </tr>
        </thead>

        <tbody class="border-bottom">
            <?php if ($this ->denniVysledky ->zobrazitMesicniKontroly == 2  ||  $this ->denniVysledky ->zobrazitMesicniKontroly == 3) {
                $this->renderMesicniKontroly();
            } ?>

            <?php foreach ($this ->denniVysledky ->f_data as $index => $radek) {
                $cssClass = Kalendar::getStyleForDate($this ->database, $radek ->datum, true, $this ->denniVysledky ->kalendar);
                if ($radek ->f_class) {
                    $cssClass .= ' ' . $radek ->f_class;
                }

                $classStr = $cssClass ? "class='$cssClass'" : '';

                $styleStr = ($this ->denniVysledky ->obarvitKontroly  && isset($radek ->barvaRadku))
                    ? 'style="background-color: ' . GuiUtils::getHtmlColor($radek ->barvaRadku) . ' !important"'
                    : '';
            ?>
                <tr <?=$classStr?> <?= $styleStr ?> data-ron-datum="<?= date('j.n.Y', $radek ->datum) ?>">
                    <?php $this ->zobrazRadek($index); ?>
                </tr>
            <?php } ?>
        </tbody>

        <tbody>
            <?php $this ->renderTableFooter(); ?>
        </tbody>

        <?php $this ->renderTableEnd(); ?>

        <input type="hidden" name="zpracovana_dochazka" value="1" />

        <?php
            // (editovatelne) mesicni vysledky
            if ($this ->editaceMesicnich1) {
                echo '<div id="zpracovanadochazka_mv1">';
                $this ->editaceMesicnich1 ->zobrazData();
                echo '</div>';
            }

            if ($this ->editaceMesicnich2) {
                echo '<div id="zpracovanadochazka_mv2">';
                $this ->editaceMesicnich2 ->zobrazData();
                echo '</div>';
            }

            if ( $this ->editaceMesicnich1 || $this ->editaceMesicnich2 ) $this ->jeEdit = true;

            if ($this ->denniVysledky ->existujeTlacitko('vlozitdokument')) {
                // dokumenty - zobrazuje je jen kdyz je pro ne tlacitko
                //if ($this->f_povoliteditaci) { - podminka odstranena 22.6.2015 - neslo smazat dokumenty, i kdyz mel prava na vkladani
                    // smazani dokumentu (pole nastavuje javascript)
                    echo '<input type="hidden" name="deleteDocumentId" id="deleteDocumentId" value="" />';

                    $pravoDoc = Prava::vratPrava('editacedokument');
                    $jePravoDoc = $pravoDoc->lzeZobrazitPP($this ->denniVysledky ->pp ->idPP, $this ->denniVysledky ->datumOd, $this ->denniVysledky ->datumDo);
                //}
                DokumentyDochazkyBrowser::zobrazDokumentyDochazky($this ->database, $this->denniVysledky->pp, $this ->denniVysledky ->datumOd, $jePravoDoc);
            }
        ?>

        <!-- tlacitka dole -->
        <div class="buttons">
            <span class="zpracovana_tlacitka3">
                <?php $this ->zobrazTlacitka(3); ?>
            </span>

            <span class="float-right zpracovana_tlacitka4">
                <?php $this ->zobrazTlacitka(4); ?>
            </span>
        </div>

        <?php if ($this ->povolitEditaci) { ?>
        <div id="zpracovana_tlacitka_float" class="zpracovana_tlacitka_float" style="display:none">
            <div>
                <input name="smazatvybrane" class="button" type="submit" value="<?= \Ron\ronText('Smazat_vybrane') ?>">
            </div>
            <?php $this ->zobrazTlacitka(5); // v panelu  ?>
            <input type="hidden" name="vybranedny" value="">
        </div>
        <?php } ?>

    </form>

    <div id="zpracovana_reports">
        <!-- seznam reportu - musi byt mimo FORM! -->
        <?php
            FormReportsListView::renderReportList($this ->reportList,
                '?menuid=zpracovanadochazka&action=report&idpp=' . $this ->denniVysledky ->pp ->idPP . '&obdobi=' . DateUtils::dateToUrlString($this ->denniVysledky ->datumOd));
        ?>
    </div>

    <?php
    // dialog s vysledky kontrol
    if ( sizeof($this ->denniVysledky ->kontroly) ) {
        VysledekKontroly::zobrazDialogKontrol($this ->denniVysledky ->kontroly);
    }
    ?>

    <?php if ($pk_dialog) { ?>
        <?php $pk_dialog ->renderHead(); ?>
            <div>
                <div><?= \Ron\ronText('Datum') ?>: <span id="zpracovana_pk_datum"></span></div>
                <div><?= \Ron\ronText('Kalendar') ?>: <span id="zpracovana_pk_kalendar"></span></div>
                <div><?= \Ron\ronText('Vyberte_smenu') ?></div>
                <select name="smenaPK" id="zpracovana_pk_smena">
                    <option value=""></option>
                </select>
                <div id="zpracovana_pk_podrobnosti"></div>
            </div>
        <?php $pk_dialog ->renderTail(); ?>
    <?php } ?>
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/editace/view_zpracovana.php <==
<?php
/**
 * stanislav.elbl, 18.06.2015
 */

namespace RonPortal\Editace;

/**
 * @var ZpracovanaDochazkaBrowser $this
 */

use Ron\DateUtils;
use Ron\Dialog;
use Ron\DialogButton;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\FormReportsListView;
use RonPortal\Dochazka\VysledekKontroly;
use RonPortal\Kalendar;
use RonPortal\Prava;
use RonPortal\Security;

$this ->jeEdit = true; // POZOR! Musi byt, aby byla videt tlacitka, pokud jsou nahore

if ($this ->denniVysledky ->existujeTlacitko('pk_zmenitsmenu')) {
    /** @var Dialog $pk_dialog */
    $pk_dialog = (new Dialog())
        ->setTitle(\Ron\ronText('Zmena_naplanovane_smeny'))
        ->setId('zpracovana_pk_zmenitsmenu')
        ->setWaitMessage(true)
        ->addButton(
            (new DialogButton())
                ->setId('btn_pk_OK')
                ->setValue(\Ron\ronText('Provest'))
        )
        ->addButton(
            (DialogButton::cancelButton('btn_pk_Storno'))
        );

//<!--            <input type="button" id="btn_pk_Storno" class="button" value="--><?//= \Ron\ronText('Cancel')
} else {
    $pk_dialog = null;
}



?>
<style>
    .graficka_timediv { width: <?= $this ->grafickaWidth ?>px }

    <?php if ($this ->denniVysledky ->style) {?>
        <?= $this ->denniVysledky ->style ?>
    <?php } ?>
</style>
<div id="zpracovanadochazka">
    <form class="sendPosition" name="zpracovanadochazkaform" id="zpracovanadochazkaform" method="post" action="?menuid=zpracovanadochazka" >

        <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->denniVysledky ->datumOd) ?>" />
        <input type="hidden" name="osoba" value="<?= $this ->denniVysledky ->pp ->idPP ?>" />

        <input type="hidden" name="x" value="" />
        <input type="hidden" name="y" value="" />

        <?= Security::csrfHiddenInput() ?>

        <!-- tlacitka nahore -->
        <div class="buttons">
            <input type="submit" style="width:0; height:0; margin:0; padding:0; border: 0" value="" /> <!-- defaultni submit kvuli enter -->
            <span class="zpracovana_tlacitka1">
                <?php $this ->zobrazTlacitka(1); // vlevo nahore  ?>
            </span>

            <?php $this ->volbaZobrazeni(); ?>

            <span class="float-right zpracovana_tlacitka2">
                <?php $this ->zobrazTlacitka(2); // vpravo nahore ?>
            </span>
        </div>


        <?php
            $this ->jeEdit = false;
            $this ->renderTableStart();
        ?>

        <thead class="floating-table-header">
            <tr>
                <?php
                    for ($i = 0; $i < count($this ->denniVysledky ->sloupce); $i++) {
                        if ($this ->denniVysledky ->sloupce[$i] ->typ  &&  $this ->denniVysledky ->sloupce[$i] ->lzeZobrazit) {
                            $this->zobrazHlavickuSloupce($i);
                        }
                    }
                ?>
            </tr>
        </thead>

        <tbody class="border-bottom">
            <?php if ($this ->denniVysledky ->zobrazitMesicniKontroly == 2  ||  $this ->denniVysledky ->zobrazitMesicniKontroly == 3) {
                $this->renderMesicniKontroly();
            } ?>

            <?php foreach ($this ->denniVysledky ->f_data as $index => $radek) {
                $cssClass = Kalendar::getStyleForDate($this ->database, $radek ->datum, true, $this ->denniVysledky ->kalendar);
                if ($radek ->cssClass) {
                    $cssClass .= ' ' . $radek ->cssClass;
                }

                $classStr = $cssClass ? "class='$cssClass'" : '';

                $styleStr = ($this ->denniVysledky ->obarvitKontroly  && isset($radek ->barvaRadku))
                    ? 'style="background-color: ' . GuiUtils::getHtmlColor($radek ->barvaRadku) . ' !important"'
                    : '';
            ?>
                <tr <?=$classStr?> <?= $styleStr ?> data-ron-datum="<?= date('j.n.Y', $radek ->datum) ?>">
                    <?php $this ->zobrazRadek($index); ?>
                </tr>
            <?php } ?>
        </tbody>

        <tbody>
            <?php $this ->renderTableFooter(); ?>
        </tbody>

        <?php $this ->renderTableEnd(); ?>

        <input type="hidden" name="zpracovana_dochazka" value="1" />

        <?php
            // (editovatelne) mesicni vysledky
            if ($this ->editaceMesicnich1) {
                echo '<div id="zpracovanadochazka_mv1">';
                $this ->editaceMesicnich1 ->zobrazData();
                echo '</div>';
            }

            if ($this ->editaceMesicnich2) {
                echo '<div id="zpracovanadochazka_mv2">';
                $this ->editaceMesicnich2 ->zobrazData();
                echo '</div>';
            }

            if ( $this ->editaceMesicnich1 || $this ->editaceMesicnich2 ) $this ->jeEdit = true;

            if ($this ->denniVysledky ->existujeTlacitko('vlozitdokument')) {
                // dokumenty - zobrazuje je jen kdyz je pro ne tlacitko
                //if ($this->f_povoliteditaci) { - podminka odstranena 22.6.2015 - neslo smazat dokumenty, i kdyz mel prava na vkladani
                    // smazani dokumentu (pole nastavuje javascript)
                    echo '<input type="hidden" name="deleteDocumentId" id="deleteDocumentId" value="" />';

                    $pravoDoc = Prava::vratPrava('editacedokument');
                    $jePravoDoc = $pravoDoc->lzeZobrazitPP($this ->denniVysledky ->pp ->idPP, $this ->denniVysledky ->datumOd, $this ->denniVysledky ->datumDo);
                //}
                DokumentyDochazkyBrowser::zobrazDokumentyDochazky($this ->database, $this->denniVysledky->pp, $this ->denniVysledky ->datumOd, $jePravoDoc);
            }
        ?>

        <!-- tlacitka dole -->
        <div class="buttons">
            <span class="zpracovana_tlacitka3">
                <?php $this ->zobrazTlacitka(3); ?>
            </span>

            <span class="float-right zpracovana_tlacitka4">
                <?php $this ->zobrazTlacitka(4); ?>
            </span>
        </div>

        <?php if ($this ->povolitEditaci) { ?>
        <div id="zpracovana_tlacitka_float" class="zpracovana_tlacitka_float" style="display:none">
            <div>
                <input name="smazatvybrane" class="button" type="submit" value="<?= \Ron\ronText('Smazat_vybrane') ?>">
            </div>
            <?php $this ->zobrazTlacitka(5); // v panelu  ?>
            <input type="hidden" name="vybranedny" value="">
        </div>
        <?php } ?>

    </form>

    <div id="zpracovana_reports">
        <!-- seznam reportu - musi byt mimo FORM! -->
        <?php
            FormReportsListView::renderReportList($this ->reportList,
                '?menuid=zpracovanadochazka&action=report&idpp=' . $this ->denniVysledky ->pp ->idPP . '&obdobi=' . DateUtils::dateToUrlString($this ->denniVysledky ->datumOd));
        ?>
    </div>

    <?php
    // dialog s vysledky kontrol
    if ( sizeof($this ->denniVysledky ->kontroly) ) {
        VysledekKontroly::zobrazDialogKontrol($this ->denniVysledky ->kontroly);
    }
    ?>

    <?php if ($pk_dialog) { ?>
        <?php $pk_dialog ->renderHead(); ?>
            <div>
                <div><?= \Ron\ronText('Datum') ?>: <span id="zpracovana_pk_datum"></span></div>
                <div><?= \Ron\ronText('Kalendar') ?>: <span id="zpracovana_pk_kalendar"></span></div>
                <div><?= \Ron\ronText('Vyberte_smenu') ?></div>
                <select name="smenaPK" id="zpracovana_pk_smena">
                    <option value=""></option>
                </select>
                <div id="zpracovana_pk_podrobnosti"></div>
            </div>
        <?php $pk_dialog ->renderTail(); ?>
    <?php } ?>

    <?php if ($this ->denniVysledky ->existujeSloupec('COPY')) { ?>
        <!-- dialog pro kopii dne -->
        <div class="rondialog ronform smallform" id="kopie_dne_dochazky_dialog" title="<?= TextManager::_('Kopie_dne_dochazky') ?>">
            <form method="post">
                <input type="hidden" name="kopieDne" value="1" />
                <input type="hidden" name="datum" class="ronform-field" />
                <input type="hidden" name="obdobi" value="<?= DateUtils::dateToUrlString($this ->denniVysledky ->datumOd) ?>" />
                <input type="hidden" name="osoba" value="<?= $this ->denniVysledky ->pp ->idPP ?>" />
                <?= Security::csrfHiddenInput() ?>

                <div>
                    <table>
                        <tr>
                            <td class="caption"><?= TextManager::_('Zkopirovat_den') ?></td>
                            <td class="ronform-field font-weight-bold" data-ronform-field-name="popiszdroje"></td>
                        </tr>

                        <tr>
                            <td class="caption"><label for="kopie_dne_datum_od"><?= TextManager::_('Datum_od') ?></label></td>
                            <td class="ronform-field font-weight-bold">
                                <input class="inputDate ronform-field" id="kopie_dne_datum_od" name="datumOd" size="10" data-ronform-field-name="datumod"
                                       data-roncalendar-mindate="<?= StringUtils::format('date', $this ->denniVysledky ->datumOd) ?>"
                                       data-roncalendar-maxdate="<?= StringUtils::format('date', $this ->denniVysledky ->datumDo) ?>"
                                       data-roncalendar-next="datumDo"
                                    />
                                <i class="inline-glyph glyph-button fa glyph-calendar showcalendar" data-roncalendar-inputname="datumOd" data-roncalendar>
                            </td>
                        </tr>

                        <tr>
                            <td class="caption"><label for="kopie_dne_datum_do"><?= TextManager::_('Datum_do') ?></label></td>
                            <td class="ronform-field font-weight-bold">
                                <input class="inputDate ronform-field" id="kopie_dne_datum_od" name="datumDo" size="10" data-ronform-field-name="datumdo"
                                       data-roncalendar-mindate="<?= StringUtils::format('date', $this ->denniVysledky ->datumOd) ?>"
                                       data-roncalendar-maxdate="<?= StringUtils::format('date', $this ->denniVysledky ->datumDo) ?>"
                                       data-roncalendar-prev="datumOd"
                                    />
                                <i class="inline-glyph glyph-button fa glyph-calendar showcalendar" data-roncalendar-inputname="datumDo">
                            </td>
                        </tr>

                        <tr>
                            <td class="caption"></td>
                            <td class=""><label><input type="checkbox" name="pouzePrazdneDny" checked="checked" value="1"> <?= TextManager::_('Kopirovat_pouze_do_prazdnych_dnu') ?></label></td>
                        </tr>

                        <tr>
                            <td class="caption"></td>
                            <td class=""><label><input type="checkbox" name="pouzeDnySeSmenou" checked="checked" value="1"> <?= TextManager::_('Kopirovat_pouze_do_dnu_se_smenou') ?></label></td>
                        </tr>

                    </table>
                </div>

                <!-- TODO: jen vybrane dny -->

                <div class="buttons">
                    <button id="kopie_dne_dochazky_ok" type="button" class="actionButton submitbutton"><?= TextManager::_('OK') ?></button>
                    <button id="kopie_dne_dochazky_storno" type="button" class="button cancel"><?= TextManager::_('Cancel') ?></button>
                </div>
            </form>
        </div>
    <?php } ?>
</div>
